﻿//Start new empty object to isolate variables and code from Global space. This helps prevent accidental changes at the Golbal level that can break other scripts from running.
{
	/*
			High Pass v2.0 ©2013-2020
			Script for After Effects
			Build technique based on Malltannon's High Pass video tutorial originally located here http://maltaannon.com/articles/after-effects/high-pass/ but has since closed it appears.
			Developer: David Torno
			About: Used to assist in creating contrast in footage to make 2D/3D motion tracking easier. In some cases it can reveal details not normally seen by human eyes to assist in tracking.

			Change Log:
			v1.0
				- Initial Release

			v2.0
				- Cleaned up code
				- Fast Box Blur now replaces the obsolete legacy Fast Blur plugin.
				- Added Fast Box Blur plugin to Controller by default for smoothing over additional noisy details.
				- Added more comments
	*/
	try{
		var proj = app.project;
		var curComp = proj.activeItem;

		//Misc variable initialize
		var selLayer, selLayerCount, curLayer, curIndex, curLabel;
		var addL, hpe1, hpe2;
		var controller, ce1, ce2, ce3, ce4;

		if(curComp instanceof CompItem){
			selLayer = curComp.selectedLayers;
			selLayerCount = selLayer.length;
			if(selLayerCount == 1){	//Verify one layer is selected
				app.beginUndoGroup("Apply High Pass");	//Begin capturing for Undo
					curLayer = selLayer[0];
					if(curLayer.source.mainSource instanceof FileSource || curLayer.source instanceof CompItem){ //Verify that layer source is a file or a comp
						curIndex = curLayer.index;
						curLabel = curLayer.label;
						
						//Create solid "Controller" layer
						controller = curComp.layers.addSolid([0.0, 0.0, 0.0], "Highpass Intensity Controller", curComp.width, curComp.height, curComp.pixelAspect, curComp.duration);
						controller.adjustmentLayer = true;
						controller.label = curLabel;
						controller.moveBefore(curLayer); //Move layer above selected layer

						//Apply Hue plugin
						ce1 = controller.property("ADBE Effect Parade").addProperty("ADBE HUE SATURATION");
							ce1.name = "Desat(do not touch)";	//Rename plugin
							ce1.property("ADBE HUE SATURATION-0005").setValue(-100);	//Set default value

						//Apply Levels plugin
						ce2 = controller.property("ADBE Effect Parade").addProperty("ADBE Easy Levels2");
							ce2.name = "Black/Gamma/White";	//Rename plugin

						//Apply Slider plugin
						ce3 = controller.property("ADBE Effect Parade").addProperty("ADBE Slider Control");
							ce3.name = "Highpass threshold";	//Rename plugin
							ce3.property("ADBE Slider Control-0001").setValue(6.0);	//Set default value

						//Apply Fast Box Blur plugin
						ce4 = controller.property("ADBE Effect Parade").addProperty("ADBE Box Blur2");
							ce4.name = "Soften";	//Rename plugin
							ce4.property("ADBE Box Blur2-0001").setValue(1.0);	//Set default value
							ce4.property("ADBE Box Blur2-0004").setValue(true);	//Set default value

						//Create High Pass effect layer (requires duplicate of selected layer)
						addL = curLayer.duplicate();
							if(addL.hasAudio == true){
								addL.audioEnabled = false;
							}
							addL.label = 0;
							addL.name = "Highpass layer (do not touch)";	//Rename layer
							addL.moveBefore(curLayer);	//Place above selected layer
							addL.blendingMode = BlendingMode.LINEAR_LIGHT;	//Set BlendMode value
							addL.property("ADBE Transform Group").property("ADBE Opacity").setValue(50);	//Set opacity

							//Apply Invert plugin
							hpe1 = addL.property("ADBE Effect Parade").addProperty("ADBE Invert");

							//Apply Fast Box Blur plugin
							hpe2 = addL.property("ADBE Effect Parade").addProperty("ADBE Box Blur2");
								hpe2.property("ADBE Box Blur2-0001").expression = "thisComp.layer(\"Highpass Intensity Controller\").effect(\"Highpass threshold\")(\"Slider\")"; //Set expression
								hpe2.property("ADBE Box Blur2-0004").setValue(true); //Set default value
							addL.locked = true;	//Lock layer
						addL.selected = false;	//Deselects layer
						controller.selected = true;	//Selects "Controller" layer
					}
			}else{
				//Warning popup if nothing selected or more than one layer is selected
				alert("Please select one layer.");
			}
		}else{
			//Warning popup is no comp is open or selected
			alert("Please make sure a composition is open and active.");
		}
	//Will catch errors tht occur while running the code, and display the line number and the error that occured
	}catch(e){alert(e.line.toString()+e.toString())}
}